explorator library

Classes

Explorator
MaterialRouteBuilder
Material implementation of the RouteBuilder.
RegisteredRoute
Describes a route
RouteArguments
A helper class which can be injected to routes.
RouteBuilder
The RouteBuilder is used to create Routes.
RouteExpressionBuilder
Provides functionality for converting route paths to expressions.
RouteMatcher
The RouteMatcher is used to match raw paths (/books/1234) against the registered routes.
RouteProvider
This interface describe a object that can provide routes.
RouteResolver
The RouteResolver is used to resolve Routes from RouteSettings. All possible routes are provided by the RouteProviders which are injected by the routeProvider tag.
Routing
Provides logic for routing

Extensions

ExploratorExtension on AbstractServiceContainer
ServiceProviderExtension on AbstractServiceContainer
This extension simplifies the configuration for the explorator package.

Exceptions / Errors

UnbalancedCurlyBracesException
Is thrown when curly are unbalanced.
UnexpectedCharException
Is thrown when a unexpected character occurs.