RouteMatcher class

The RouteMatcher is used to match raw paths (/books/1234) against the registered routes.

Annotations
  • @Service.new()

Constructors

RouteMatcher(@Inject.new(tag: RouteProvider.tag) List<RouteProvider> routeProviders)
Creates a new Route Matcher. The known routes are provided by the routeProviders.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

match(String path) RegisteredRoute?
Returns the route that matches against the path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited